=======
History
=======

1.4.0 (2022-05-10)
------------------

* Fixed minor API bugs
* Fixed documentation
* Added cli overwrite prompt
* New messaging system
* New prompt system
* Updates to the progress UI
* Renamed callback module to callbacks
* Refactored messaging to user
* Better package information
* Added --overwrite and --version to options for CLI tools

1.3.0 (2022-05-04)
------------------

* Added project class
* Updated messages for skipped files
* Fixed same key calculation
* Code cleanup
* Refactored CLI - Removed duplicated code

1.2.1 (2022-04-26)
------------------

* Fixed history
* Callback class to make life easier internally

1.2.0 (2022-04-21)
------------------

* Added overwrite handling in the GUI

1.1.1 (2022-04-18)
------------------

* Fixing tag issue
* Fixing release build

1.1.0 (2022-04-18)
------------------

* Documentation changes
* GUI changes

1.0.3 (2022-04-18)
------------------

* Bumping version to fix out of order upload to pypi

1.0.2 (2022-04-15)
------------------

* Fixed history file
* Fixed documentation link

1.0.0 (2022-04-15)
------------------

* Added about dialog
* Production ready

0.3.4 (2022-04-14)
------------------

* Updating actions to publish properly
* Documentation updates

0.3.3 (2022-04-14)
------------------

* Fix to GitHub actions

0.3.2 (2022-04-14)
------------------

* Automate the release process

0.3.1 (2022-04-13)
------------------

* Fixes to documentation

0.3.0 (2022-04-13)
------------------

* Added icons
* Added encoding
* Changed exe name
* UPX packing on Windows
* Documentation updates

0.2.4 (2022-04-06)
------------------

* More testing
* Bump2Version configuration fixes
* Fixing up tox.ini

0.2.3 (2022-04-01)
------------------

* Added tests

0.2.2 (2022-04-01)
------------------

* Fixed documentation
* Fixed exceptions

0.2.1 (2022-03-31)
------------------

* Bug fixes

0.2.0 (2022-03-30)
------------------

* Added GUI

0.1.1 (2022-03-23)
------------------

* Faster key detection
* Python typing
* Added documentation
* Keeping files compatible with RPGMaker MV/MZ
  * Using .png or .ogg instead of real extension

0.1.0 (2021-04-18)
------------------

* First release on PyPI.
